@@ -14,7 +14,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #include "SKP_Silk_SDK_API.h"
 #include "mediastreamer2/msfilter.h"
@@ -329,9 +329,9 @@ extern MSFilterDesc ms_silk_dec_desc;
 #define MS_PLUGIN_DECLARE(type) type
 #endif
 
-MS_PLUGIN_DECLARE ( void ) libmssilk_init() {
-	ms_filter_register ( &ms_silk_enc_desc );
-	ms_filter_register ( &ms_silk_dec_desc );
+MS_PLUGIN_DECLARE ( void ) libmssilk_init(MSFactory* factory) {
+	ms_factory_register_filter(factory, &ms_silk_enc_desc );
+	ms_factory_register_filter(factory, &ms_silk_dec_desc );
 	ms_message ( " libmssilk " VERSION " plugin loaded" );
 }
 
